@@ -40,8 +40,7 @@ CATEGORY_MAP = {
     "cien"           : "Ci-en",
     "cohost"         : "cohost!",
     "comicvine"      : "Comic Vine",
-    "coomerparty"    : "Coomer",
-    "deltaporno"     : "DeltaPorno",
+    "dankefuerslesen": "Danke fürs Lesen",
     "deviantart"     : "DeviantArt",
     "drawfriends"    : "Draw Friends",
     "dynastyscans"   : "Dynasty Reader",
@@ -57,6 +56,7 @@ CATEGORY_MAP = {
     "fashionnova"    : "Fashion Nova",
     "furaffinity"    : "Fur Affinity",
     "furry34"        : "Furry 34 com",
+    "girlswithmuscle": "Girls with Muscle",
     "hatenablog"     : "HatenaBlog",
     "hbrowse"        : "HBrowse",
     "hentai2read"    : "Hentai2Read",
@@ -90,8 +90,7 @@ CATEGORY_MAP = {
     "itchio"         : "itch.io",
     "jpgfish"        : "JPG Fish",
     "kabeuchi"       : "かべうち",
-    "kemonoparty"    : "Kemono",
-    "koharu"         : "SchaleNetwork",
+    "schalenetwork"  : "Schale Network",
     "livedoor"       : "livedoor Blog",
     "lofter"         : "LOFTER",
     "ohpolly"        : "Oh Polly",
@@ -100,11 +99,9 @@ CATEGORY_MAP = {
     "mangafox"       : "Manga Fox",
     "mangahere"      : "Manga Here",
     "mangakakalot"   : "MangaKakalot",
-    "mangalife"      : "MangaLife",
     "manganato"      : "MangaNato",
     "mangapark"      : "MangaPark",
     "mangaread"      : "MangaRead",
-    "mangasee"       : "MangaSee",
     "mariowiki"      : "Super Mario Wiki",
     "mastodon.social": "mastodon.social",
     "mediawiki"      : "MediaWiki",
@@ -112,20 +109,26 @@ CATEGORY_MAP = {
     "myhentaigallery": "My Hentai Gallery",
     "myportfolio"    : "Adobe Portfolio",
     "natomanga"      : "MangaNato",
-    "naverwebtoon"   : "NaverWebtoon",
+    "naver-blog"     : "Naver Blog",
+    "naver-chzzk"    : "CHZZK",
+    "naver-webtoon"  : "Naver Webtoon",
     "nelomanga"      : "MangaNelo",
     "nhentai"        : "nhentai",
     "nijie"          : "nijie",
     "nozomi"         : "Nozomi.la",
     "nsfwalbum"      : "NSFWalbum.com",
-    "paheal"         : "rule #34",
+    "nudostar"       : "NudoStar.TV",
+    "paheal"         : "Rule 34",
     "photovogue"     : "PhotoVogue",
     "pidgiwiki"      : "PidgiWiki",
     "pixeldrain"     : "pixeldrain",
+    "pixiv"          : "[pixiv]",
+    "pixiv-novel"    : "[pixiv] Novels",
     "pornimage"      : "Porn Image",
     "pornpics"       : "PornPics.com",
     "pornreactor"    : "PornReactor",
     "readcomiconline": "Read Comic Online",
+    "redbust"        : "RedBust",
     "rbt"            : "RebeccaBlackTech",
     "redgifs"        : "RedGIFs",
     "rozenarcana"    : "Rozen Arcana",
@@ -164,7 +167,7 @@ CATEGORY_MAP = {
     "vsco"           : "VSCO",
     "wallpapercave"  : "Wallpaper Cave",
     "webmshare"      : "webmshare",
-    "webtoons"       : "Webtoon",
+    "webtoons"       : "WEBTOON",
     "weebcentral"    : "Weeb Central",
     "wikiart"        : "WikiArt.org",
     "wikigg"         : "wiki.gg",
@@ -188,7 +191,6 @@ SUBCATEGORY_MAP = {
     "issue"  : "Comic Issues",
     "manga"  : "Manga",
     "media"  : "Media Files",
-    "note"   : "Images from Notes",
     "popular": "Popular Images",
     "recent" : "Recent Images",
     "search" : "Search Results",
@@ -197,9 +199,10 @@ SUBCATEGORY_MAP = {
     "tweets" : "",
     "user"   : "User Profiles",
     "watch"  : "Watches",
-    "following"    : "Followed Users",
-    "related-pin"  : "related Pins",
-    "related-board": "",
+    "direct-messages": "DMs",
+    "following"      : "Followed Users",
+    "related-pin"    : "related Pins",
+    "related-board"  : "",
 
     "ao3": {
         "user-works"   : "",
@@ -221,18 +224,20 @@ SUBCATEGORY_MAP = {
         "posts": "",
     },
     "boosty": {
-        "direct-messages": "DMs",
         "feed": "Subscriptions Feed",
     },
     "civitai": {
         "models": "Model Listings",
         "images": "Image Listings",
+        "posts" : "Post Listings",
+        "search-models": "Model Searches",
+        "search-images": "Image Searches",
         "user-models": "User Models",
-        "user-images": "User Images",
+        "user-images": ("User Images", "Image Reactions"),
         "user-posts" : "User Posts",
-        "user-videos": "User Videos",
+        "user-videos": ("User Videos", "Video Reactions"),
     },
-    "coomerparty": {
+    "coomer": {
         "discord"       : "",
         "discord-server": "",
         "posts"         : "",
@@ -251,7 +256,6 @@ SUBCATEGORY_MAP = {
         "watch-posts": "",
     },
     "discord": {
-        "direct-messages": "DMs",
         "direct-message" : "",
     },
     "fanbox": {
@@ -283,7 +287,12 @@ SUBCATEGORY_MAP = {
         "saved": "Saved Posts",
         "tagged": "Tagged Posts",
     },
-    "kemonoparty": {
+    "iwara": {
+        "user-images": "User Images",
+        "user-videos": "User Videos",
+        "user-playlists": "User Playlists",
+    },
+    "kemono": {
         "discord"       : "Discord Servers",
         "discord-server": "",
         "posts"         : "",
@@ -299,6 +308,10 @@ SUBCATEGORY_MAP = {
         "following" : "Library",
         "list": "MDLists",
     },
+    "misskey": {
+        "note" : "Notes",
+        "notes": "User Notes",
+    },
     "nijie": {
         "followed": "Followed Users",
         "nuita" : "Nuita History",
@@ -333,6 +346,9 @@ SUBCATEGORY_MAP = {
         "post"           : "Individual Posts",
         "shorturl"       : "",
     },
+    "redbust": {
+        "gallery": ("Galleries", "Categories"),
+    },
     "redgifs": {
         "collections": "",
     },
@@ -443,7 +459,7 @@ AUTH_MAP = {
     "bluesky"        : "Supported",
     "booruvar"       : "Supported",
     "boosty"         : _COOKIES,
-    "coomerparty"    : "Supported",
+    "coomer"         : "Supported",
     "danbooru"       : "Supported",
     "derpibooru"     : _APIKEY_DB,
     "deviantart"     : _OAUTH,
@@ -458,12 +474,14 @@ AUTH_MAP = {
     "flickr"         : _OAUTH,
     "furaffinity"    : _COOKIES,
     "furbooru"       : "API Key",
+    "girlswithmuscle": "Supported",
     "horne"          : "Required",
     "idolcomplex"    : "Supported",
     "imgbb"          : "Supported",
     "inkbunny"       : "Supported",
     "instagram"      : _COOKIES,
-    "kemonoparty"    : "Supported",
+    "iwara"          : "Supported",
+    "kemono"         : "Supported",
     "mangadex"       : "Supported",
     "mangoxo"        : "Supported",
     "mastodon.social": _OAUTH,
@@ -476,6 +494,7 @@ AUTH_MAP = {
     "pixiv"          : _OAUTH,
     "ponybooru"      : "API Key",
     "reddit"         : _OAUTH,
+    "rule34xyz"      : "Supported",
     "sankaku"        : "Supported",
     "scrolller"      : "Supported",
     "seiga"          : "Supported",
@@ -555,7 +574,7 @@ def subcategory_text(bc, c, sc):
 
 def category_key(c):
     """Generate sorting keys by category"""
-    return category_text(c[0]).lower()
+    return category_text(c[0]).lower().lstrip("[")
 
 
 def subcategory_key(sc):
@@ -599,17 +618,15 @@ def build_extractor_list():
         for subcategories in base.values():
             subcategories.sort(key=subcategory_key)
 
+    domains["pixiv-novel"] += "novel"
+
     # add e-hentai.org
     default["e-hentai"] = default["exhentai"]
     domains["e-hentai"] = domains["exhentai"].replace("x", "-")
 
-    # add coomer.party
-    default["coomerparty"] = default["kemonoparty"]
-    domains["coomerparty"] = domains["kemonoparty"].replace("kemono", "coomer")
-
-    # add manga4life.com
-    default["mangalife"] = default["mangasee"]
-    domains["mangalife"] = "https://manga4life.com/"
+    # add coomer.su
+    default["coomer"] = default["kemono"]
+    domains["coomer"] = domains["kemono"].replace("kemono", "coomer")
 
     # add wikifeetx.com
     default["wikifeetx"] = default["wikifeet"]
