@@ -123,7 +123,7 @@ __tests__ = (
     "#url"     : "https://mangadex.org/titles/follows",
     "#class"   : mangadex.MangadexFollowingExtractor,
     "#auth"    : True,
-    "#urls"    : (
+    "#results" : (
         "https://mangadex.org/title/cad76ec6-ca22-42f6-96f8-eca164da6545",
         "https://mangadex.org/title/7546ff2d-2310-47a4-b1f3-1a2561f20ce7",
     ),
@@ -139,7 +139,7 @@ __tests__ = (
     "#url"     : "https://mangadex.org/list/3a0982c5-65aa-4de2-8a4a-2175be7383ab/test",
     "#category": ("", "mangadex", "list"),
     "#class"   : mangadex.MangadexListExtractor,
-    "#urls"    : (
+    "#results" : (
         "https://mangadex.org/title/cba4e5d6-67a0-47a0-b37a-c06e9bf25d93",
         "https://mangadex.org/title/cad76ec6-ca22-42f6-96f8-eca164da6545",
     ),
@@ -155,7 +155,7 @@ __tests__ = (
     "#url"     : "https://mangadex.org/list/3a0982c5-65aa-4de2-8a4a-2175be7383ab/test?tab=feed",
     "#category": ("", "mangadex", "list-feed"),
     "#class"   : mangadex.MangadexListExtractor,
-    "#urls"    : (
+    "#results" : (
         "https://mangadex.org/chapter/c765d6d5-5712-4360-be0b-0c8e0914fc94",
         "https://mangadex.org/chapter/fa8a695d-260f-4dcc-95a3-1f30e66d6571",
         "https://mangadex.org/chapter/788766b9-41c6-422e-97ba-552f03ba9655",
@@ -165,7 +165,7 @@ __tests__ = (
 {
     "#url"     : "https://mangadex.org/author/7222d0d5-836c-4bf3-9174-72bceade8c87/kotoyama",
     "#class"   : mangadex.MangadexAuthorExtractor,
-    "#urls"    : (
+    "#results" : (
         "https://mangadex.org/title/ef4ead73-57a7-4d10-95b3-de73cfdd2670",
         "https://mangadex.org/title/259dfd8a-f06a-4825-8fa6-a2dcd7274230",
         "https://mangadex.org/title/d0c88e3b-ea64-4e07-9841-c1d2ac982f4a",
